.. _glossary:

============================
Glossary
============================

.. glossary::

  O-wrap
    A template which defines the document structure on a page-level;
    it typically includes stylesheets which provide the general look
    and feel of the site.
